Changelog
=========

This document describes changes between each past release.


0.4.0 (2019-09-30)
------------------

- Log version value when broadcasting to Megaphone


0.3.0 (2018-11-12)
------------------

- Add configuration to restrict what kinto-changes records cause notifications (#13).


0.2.3 (2018-11-07)
------------------

- Remove a broken log message (#10).


0.2.2 (2018-11-07)
------------------

- I failed to correctly release 0.2.1. Try again.


0.2.1 (2018-11-07)
------------------

- Add a few log messages to help try to troubleshoot.


0.2.0 (2018-09-25)
------------------

- Update to match kinto 10.1.1 -- see Kinto/kinto#1770 (#2).
- Add a heartbeat feature.


0.1.0 (2018-09-12)
------------------

- Initial implementation
